What is OiRA | OiRA

Topics

# What is OiRA

## New at OiRA?

Here you get a short introduction on what a risk assessment is and how OiRA can help you to manage it.

## What is Risk Assessment?

Risk Assessment is the basis for successful safety and health management, and the key to reducing work-related accidents and occupational diseases. If it is implemented well, it can improve workplace safety and health - and business performance in general.

Worker’s safety and health shall be protected in Europe through assessing and managing risks at work. Employers have a legal duty to ensure the safety and health of workers in every aspect related to work and to carry out a risk assessment. Every company must therefore conduct a risk assessment and draw up an action plan. In order to carry out an effective workplace risk assessment, all those involved require a clear understanding of:

- the legal context and concepts
- the process used to assess the risks
- the role to be played by the main actors involved in the process

Workers and/or their representatives have the right to be consulted on arrangements to carry out and participate in the risk assessment.

You can find more information on risk assessment and about the participation of workers and/or their representatives in the risk assessment process on the website of the OiRA project.

## What is OiRA?

OiRA stands for Online Interactive Risk Assessment. It is a web-based application that allows you to perform a health and safety risk assessment of your workplace.

## Who is OiRA for?

OiRA can be used by anyone for assessing health and safety-related risks that might exist in their workplace.

However, OiRA is designed to be of most value to smaller businesses. OiRA has been developed specifically to support them in assessing the risks at work and helping them to produce a documented risk assessment including an action plan tailored to the establishment’s requirements.

## What do I have to do?

There are several steps to be completed in the risk assessment process with OiRA:

- Preparation: Some tools have profile questions that help you target the tool to the specificities of your establishment. When you answer the profile questions, the tool will adapt to your specific situation and will show you the modules that apply to your specific situation.

- Involvement: Every risk assessment should be done with active involvement of the workers. The tool gives you the possibility to print out the full text of the risk assessment or parts of it in order to inform workers and get their feedback.

- Risk Identification: OiRA will present a series of potential health and safety hazards or problems that could exist in your workplace. By answering the statements/questions with either yes or no, you state if such hazards or problems are present. You can also decide to leave a question unanswered and thus put it on hold to be answered at a later stage.

- Evaluation: Some tools ask you to prioritise the risks you have identified. There are different ways in doing so, which depend on decisions taken by our national OiRA partners/the tool developers and their specific approach. Some tools also do the prioritisation of risks automatically in the background and you are enabled to overrule these priorities.

- Action Plan: For each identified risk the tool asks you to decide on one or more measures to eliminate or reduce the risk. Most tools propose already some measures to you. You can also always choose to enter your own measures.

- Report: You are legally required to document your risk assessment. In the report section, you find a variety of reports that will help you keep track of your risk assessment and follow up on the actions/measures that you have decided to implement in order to eliminate or mitigate the risks identified.

## How long will it take?

It’s impossible to say how long an assessment will take in general as the tools differ according to sectors and countries.

However, you can spend whatever time you have available on an assessment and then return to it when convenient to pick up from the same point you left off.

## Why do I have to register?

The first thing you will be asked to do when you begin your first risk assessment is to create an OiRA account - this is a simple and quick process.

Registering allows you to simply log in at any time to continue previous assessments or to start new ones.

If you are a registered user, you also have the option to obtain a printed, accurate and up-dated risk assessment at any time.

## Do I need to prepare?

You do not need any kind of specific preparation to start using the tool, however you should take some time to think about who is going to carry out the risk assessment, how workers are going to be involved in the process, etc.

Scroll to top
Back

## 2-what-is-oira.md

More…

- New risk assessment
- Show archived risk assessments
- All types of risk assessments Only regular risk assessments Only contractor risk assessments

Help

Standard search Advanced search